Plover Layout Display
=====================

Display the last stroke in Plover.

.. image:: https://i.imgur.com/8AqhQk4.png

Custom Layouts
----------------

You can customize the display in various ways by loading your own layout file. Layout file preferences are saved and loaded automatically for each stenography system that you use them for.

See the `Plover Layout Display Wiki <https://github.com/morinted/plover_layout_display/wiki>`__ for other layout files as well as the format to create your own.

Some examples of custom layouts:

.. image:: https://i.imgur.com/qjZ0uwn.png

|

.. image:: https://i.imgur.com/7zT77kL.png

Wishlist
--------

**Pull requests are welcome!**

This plugin isn't high on my priority list so please feel free to implement any of the below, or suggest new features.

- Add a settings area.
- Add a fade for the last chord to a user-specified time.

License
-------

This plugin is licensed under GPLv2, or any later version.
